==> okteta-0.25.3.tar.xz: okteta-0.25.3/libs/kasten/gui/controller/abstracttoolwidget_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTTOOLWIDGET_P_H
#define ABSTRACTTOOLWIDGET_P_H

// lib
#include "abstracttoolwidget.h"

class QShortcut;

namespace Kasten {

class AbstractToolWidget;

class AbstractToolWidgetPrivate
{
public:
    explicit AbstractToolWidgetPrivate(AbstractToolWidget* parent);

public:
    void addButton(QPushButton* button, AbstractToolWidget::DefaultType defaultType);

public:
    void onReturnPressed();

private:
    AbstractToolWidget* const p;

    QPushButton* mDefaultButton = nullptr;
    QShortcut* mReturnShortcut;
};

}

#endif

==> okteta_4.13.3.orig.tar.xz: okteta-4.13.3/libs/kasten/gui/controller/abstracttoolwidget_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTTOOLWIDGET_P_H
#define ABSTRACTTOOLWIDGET_P_H

// lib
#include "abstracttoolwidget.h"

class QShortcut;


namespace Kasten2
{

class AbstractToolWidget;


class AbstractToolWidgetPrivate
{
  public:
    explicit AbstractToolWidgetPrivate( AbstractToolWidget* parent );

  public:
    void addButton( QPushButton* button, AbstractToolWidget::DefaultType defaultType );

  public:
    void onReturnPressed();

  private:
    AbstractToolWidget* const p;

    QPushButton* mDefaultButton;
    QShortcut* mReturnShortcut;
};

}

#endif
